<?php

namespace Litecms\LeadershipBonus\Providers;

use Illuminate\Support\ServiceProvider;

class LeadershipBonusServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'leadership_bonus');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'leadership_bonus');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.leadership_bonus', function ($app) {
            return $this->app->make('Litecms\LeadershipBonus\LeadershipBonus');
        });

                // Bind LeadershipBonus to repository
        $this->app->bind(
            'Litecms\LeadershipBonus\Interfaces\LeadershipBonusRepositoryInterface',
            \Litecms\LeadershipBonus\Repositories\Eloquent\LeadershipBonusRepository::class
        );

        $this->app->register(\Litecms\LeadershipBonus\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\LeadershipBonus\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\LeadershipBonus\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.leadership_bonus'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/leadership_bonus.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/leadership_bonus')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/leadership_bonus')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
